@@ -17,7 +17,7 @@ our @ISA = qw( Parse::Nibbler );
 use Parse::Nibbler;
 use Data::Dumper;
 
-our $VERSION = '1.00';
+our $VERSION = '1.03';
 
 
 #############################################################################
@@ -26,7 +26,7 @@ our $VERSION = '1.00';
 sub Lexer
 #############################################################################
 {
-  my $p = shift;
+  my $p = $_[0];
 
   while(1)
     {
@@ -220,6 +220,29 @@ sub Lexer
     }
 }
 
+
+
+
+
+###############################################################################
+Register 
+( 'Number', sub 
+###############################################################################
+  {
+    $_[0]->TypeIs('Number');
+  }
+);
+
+###############################################################################
+Register 
+( 'Identifier', sub 
+###############################################################################
+  {
+    $_[0]->TypeIs('Identifier');
+  }
+);
+
+
 ###############################################################################
 ###############################################################################
 ###############################################################################
@@ -233,8 +256,7 @@ Register
 ( 'SourceText', sub 
 ###############################################################################
   {
-    my $p = shift;
-    $p->Description('{*}');
+    $_[0]->Description('{*}');
   }
 );
 
@@ -243,8 +265,7 @@ Register
 ( 'Description', sub 
 ###############################################################################
   {
-    my $p = shift;
-    $p->ModuleDeclaration;
+    $_[0]->ModuleDeclaration;
   }
 );
 
@@ -253,7 +274,7 @@ Register
 ( 'ModuleDeclaration', sub 
 ###############################################################################
   {
-    my $p = shift;
+    my $p = $_[0];
     $p->ValueIs('module');
     $p->TypeIs('Identifier');
     $p->ListOfPorts('{?}');
@@ -268,7 +289,7 @@ Register
 ( 'ListOfPorts', sub 
 ###############################################################################
   {
-    my $p = shift;
+    my $p = $_[0];
     $p->ValueIs('(');
     $p->PortList;
     $p->ValueIs(')');
@@ -280,8 +301,7 @@ Register
 ( 'PortList', sub
 ###############################################################################
   {
-    my $p = shift;
-    $p->AlternateRules( 'AnonPortExpressionList', 'NamedPortExpressionList' );
+    $_[0]->AlternateRules( 'AnonPortExpressionList', 'NamedPortExpressionList' );
   }
 );
 
@@ -291,8 +311,7 @@ Register
 ( 'NamedPortExpressionList', sub 
 ###############################################################################
   {
-    my $p = shift;
-    $p->NamedPortExpression('{+}/,/');
+    $_[0]->NamedPortExpression('{+}/,/');
   }
 );
 
@@ -301,8 +320,7 @@ Register
 ( 'AnonPortExpressionList', sub 
 ###############################################################################
   {
-    my $p = shift;
-    $p->AnonPortExpression('{+}/,/');
+    $_[0]->AnonPortExpression('{+}/,/');
   }
 );
 
@@ -327,8 +345,10 @@ Register
 ( 'AnonPortExpression', sub 
 ###############################################################################
   {
-    my $p = shift;
-    $p->AlternateRules( 'PortReference', 'ConcatenatedPortReference' );
+    $_[0]->AlternateRules
+      ( 
+       'PortReference', 'ConcatenatedPortReference', 'Number'  
+      );
   }
 );
 
@@ -337,46 +357,35 @@ Register
 ( 'PortReference', sub 
 ###############################################################################
   {
-    my $p = shift;
-    $p->AlternateRules( 'PortIdBus','PortIdOneBit', 'PortIdNoBit' );
+    my $p = $_[0];
+    $p->TypeIs('Identifier');
+    $p->BitSpecifier('{?}');
   }
 );
 
-###############################################################################
-Register 
-( 'PortIdNoBit', sub 
-###############################################################################
-  {
-    my $p = shift;
-    $p->TypeIs('Identifier');
-  }
-);
+
 
 ###############################################################################
 Register 
-( 'PortIdOneBit', sub 
+( 'BitSpecifier', sub 
 ###############################################################################
   {
-    my $p = shift;
-    $p->TypeIs('Identifier');
+    my $p = $_[0];
     $p->ValueIs('[');
     $p->TypeIs('Number');
+    $p->ColonNumber('{?}');
     $p->ValueIs(']');
   }
 );
 
 ###############################################################################
 Register 
-( 'PortIdBus', sub 
+( 'ColonNumber', sub 
 ###############################################################################
   {
-    my $p = shift;
-    $p->TypeIs('Identifier');
-    $p->ValueIs('[');
-    $p->TypeIs('Number');
+    my $p = $_[0];
     $p->ValueIs(':');
     $p->TypeIs('Number');
-    $p->ValueIs(']');
   }
 );
 
@@ -385,9 +394,9 @@ Register
 ( 'ConcatenatedPortReference', sub 
 ###############################################################################
   {
-    my $p = shift;
+    my $p = $_[0];
     $p->ValueIs('{');
-    $p->PortReference('{+} /,/');
+    $p->PortReference('{+}/,/');
     $p->ValueIs('}');
   }
 );
@@ -397,8 +406,7 @@ Register
 ( 'ModuleItem', sub 
 ###############################################################################
   {
-    my $p = shift;
-    $p->AlternateRules
+    $_[0]->AlternateRules
       ( 
        'DirectionDeclaration',
        'ModuleInstantiation'
@@ -412,7 +420,7 @@ Register
 ( 'DirectionDeclaration', sub 
 ###############################################################################
   {
-    my $p = shift;
+    my $p = $_[0];
     $p->AlternateValues('input', 'output', 'inout');
     $p->Range('{?}');
     $p->PortIdentifier('{+}');
@@ -426,8 +434,7 @@ Register
 ( 'PortIdentifier', sub 
 ###############################################################################
   {
-    my $p = shift;
-    $p->TypeIs('Identifier');
+    $_[0]->TypeIs('Identifier');
   }
 );
 
@@ -436,7 +443,7 @@ Register
 ( 'Range', sub 
 ###############################################################################
   {
-    my $p = shift;
+    my $p = $_[0];
     $p->ValueIs('[');
     $p->TypeIs('Number');
     $p->ValueIs(':');
@@ -451,7 +458,7 @@ Register
 ( 'ModuleInstantiation', sub 
 ###############################################################################
   {
-    my $p = shift;
+    my $p = $_[0];
     $p->TypeIs('Identifier');
     $p->ParameterValueAssignment('{?}');
     $p->ModuleInstance('{+}/,/');
@@ -464,7 +471,7 @@ Register
 ( 'ParameterValueAssignment', sub 
 ###############################################################################
   {
-    my $p = shift;
+    my $p = $_[0];
     $p->ValueIs('#');
     $p->ValueIs('(');
     $p->PortList('{?}');
@@ -478,7 +485,7 @@ Register
 ( 'ModuleInstance', sub 
 ###############################################################################
   {
-    my $p = shift;
+    my $p = $_[0];
     $p->TypeIs('Identifier');
     $p->ValueIs('(');
     $p->PortList('{?}');
